==> bootstrap-controls-0.1.2.tgz: package/README.md <==
# Bootstrap powered controls for styling blocks built for the WordPress block editor

A library of common block styling controls powered by [bootstrap](https://v5.getbootstrap.com/).

* [Follow us on Twitter](https://twitter.com/blockhandbook)

## Installation

```bash
npm i @blockhandbook/bootstrap-controls --save-dev
```

_This package assumes that your code will run in an ES2015+ environment._

## Setup

You need to be using bootstrap.  Getting it setup for use in WordPress can be a little tricky, which is why we put together this @blockhandbook/bootstrap package.  
[See Documentation](https://www.npmjs.com/package/@blockhandbook/tailwindcss)

## Usage

A handful of common styling controls powered by boostrap classes are bundled in this package:

### BoxShadowControls

Toolbar & InspectorControls for adding box shadow settings to blocks:
![BoxShadowControls in the WordPress block editor sidebar & toolbar](https://blockhandbook.com/wp-content/uploads/2020/05/BoxShadowControls-screenshot.png)
[See Documentation](https://github.com/blockhandbook/create-plugin/tree/master/packages/bootstrap-controls/src/controls/box-shadow-controls)

### BorderControls

Toolbar & InspectorControls for adding border settings to blocks:
![BorderControls in the WordPress block editor sidebar & toolbar](https://blockhandbook.com/wp-content/uploads/2020/05/Copy-of-BorderControls-Screenshot.png)
[See Documentation](https://github.com/blockhandbook/create-plugin/tree/master/packages/bootstrap-controls/src/border-controls)

### MarginControls

Toolbar & InspectorControls for adding margin settings to blocks:
![MarginControls in the WordPress block editor sidebar & toolbar](https://blockhandbook.com/wp-content/uploads/2020/05/MarginControls-Screenshot.png)
[See Documentation](https://github.com/blockhandbook/create-plugin/tree/master/packages/bootstrap-controls/src/margin-controls)

### PaddingControls

Toolbar & InspectorControls for adding padding settings to blocks:
![BorderControls in the WordPress block editor sidebar & toolbar](https://blockhandbook.com/wp-content/uploads/2020/05/PaddingControls-screenshot.png)
[See Documentation](https://github.com/blockhandbook/create-plugin/tree/master/packages/bootstrap-controls/src/padding-controls)

### SpacingControls

Toolbar & InspectorControls for adding spacing settings to blocks:
![SpacingControls in the WordPress block editor sidebar & toolbar](https://blockhandbook.com/wp-content/uploads/2020/05/SpacingControls-screenshot.png)
[See Documentation](https://github.com/blockhandbook/create-plugin/tree/master/packages/bootstrap-controls/src/spacing-controls)

### BackgroundControls

![BackgroundControls in the WordPress block editor sidebar & toolbar](https://blockhandbook.com/wp-content/uploads/2020/05/BackgroundControls-Screenshot.png)
[See Documentation](https://github.com/blockhandbook/create-plugin/tree/master/packages/bootstrap-controls/src/background-controls)

==> bootstrap-controls-0.1.6.tgz: package/README.md <==
# Bootstrap powered controls for styling blocks built for the WordPress block editor

A library of common block styling controls powered by [bootstrap](https://v5.getbootstrap.com/).

* [Follow us on Twitter](https://twitter.com/blockhandbook)

## Installation

```bash
npm i @blockhandbook/bootstrap-controls --save-dev
```

_This package assumes that your code will run in an ES2015+ environment._

## Setup

You need to be using bootstrap.  Getting it setup for use in WordPress can be a little tricky, which is why we put together this @blockhandbook/bootstrap package.  
[See Documentation](https://www.npmjs.com/package/@blockhandbook/bootstrap)

## Usage

A handful of common styling controls powered by boostrap classes are bundled in this package:

### BoxShadowControls

Toolbar & InspectorControls for adding box shadow settings to blocks:
![BoxShadowControls in the WordPress block editor sidebar & toolbar](https://blockhandbook.com/wp-content/uploads/2020/05/BoxShadowControls-screenshot.png)
[See Documentation](https://github.com/blockhandbook/create-plugin/tree/master/packages/bootstrap-controls/src/box-shadow-controls)

### BorderControls

Toolbar & InspectorControls for adding border settings to blocks:
![BorderControls in the WordPress block editor sidebar & toolbar](https://blockhandbook.com/wp-content/uploads/2020/05/Copy-of-BorderControls-Screenshot.png)
[See Documentation](https://github.com/blockhandbook/create-plugin/tree/master/packages/bootstrap-controls/src/border-controls)

### MarginControls

Toolbar & InspectorControls for adding margin settings to blocks:
![MarginControls in the WordPress block editor sidebar & toolbar](https://blockhandbook.com/wp-content/uploads/2020/05/MarginControls-Screenshot.png)
[See Documentation](https://github.com/blockhandbook/create-plugin/tree/master/packages/bootstrap-controls/src/margin-controls)

### PaddingControls

Toolbar & InspectorControls for adding padding settings to blocks:
![BorderControls in the WordPress block editor sidebar & toolbar](https://blockhandbook.com/wp-content/uploads/2020/05/PaddingControls-screenshot.png)
[See Documentation](https://github.com/blockhandbook/create-plugin/tree/master/packages/bootstrap-controls/src/padding-controls)

### SpacingControls

Toolbar & InspectorControls for adding spacing settings to blocks:
![SpacingControls in the WordPress block editor sidebar & toolbar](https://blockhandbook.com/wp-content/uploads/2020/05/SpacingControls-screenshot.png)
[See Documentation](https://github.com/blockhandbook/create-plugin/tree/master/packages/bootstrap-controls/src/spacing-controls)

### BackgroundControls

![BackgroundControls in the WordPress block editor sidebar & toolbar](https://blockhandbook.com/wp-content/uploads/2020/05/BackgroundControls-Screenshot.png)
[See Documentation](https://github.com/blockhandbook/create-plugin/tree/master/packages/bootstrap-controls/src/background-controls)
